@@ -1,5 +1,9 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004, 2005 Christian Persch
+ *  Copyright © 2004 Crispin Flowerday
+ *  Copyright © 2004 Adam Hooper
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,26 +17,21 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *
+ *  $Id: 
  */
 
 #ifndef EPHY_EMBED_UTILS_H
 #define EPHY_EMBED_UTILS_H
 
-#include "ephy-embed-persist.h"
-
-#include <gtk/gtkwidget.h>
-#include <bonobo/bonobo-ui-component.h>
+#include "ephy-embed.h"
 
 G_BEGIN_DECLS
 
-void ephy_embed_utils_save			(GtkWidget *window,
-						 const char *title,
-						 const char *default_dir_pref,
-						 gboolean ask_dest,
-						 EphyEmbedPersist *persist);
-
-void ephy_embed_utils_nohandler_dialog_run      (GtkWidget *parent);
+char 	   * ephy_embed_utils_link_message_parse  (char *message);
+const char * ephy_embed_utils_get_title_composite (EphyEmbed *embed);
+gboolean     ephy_embed_utils_address_has_web_scheme (const char *address);
 
 G_END_DECLS
 
