@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ContentHandler.cpp 8153 2008-03-28 15:08:18Z chpe $
+ *  $Id: ContentHandler.cpp 8257 2008-05-26 17:56:22Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -35,6 +35,7 @@
 
 #include <nsStringAPI.h>
 
+#include <nsAutoPtr.h>
 #include <nsCExternalHandlerService.h>
 #include <nsComponentManagerUtils.h>
 #include <nsIDOMWindow.h>
@@ -66,7 +67,10 @@
  * content handler.
  */
 GContentHandler::GContentHandler()
-: mUserTime(0)
+: mHelperApp(NULL),
+  mPermission(EPHY_MIME_PERMISSION_UNKNOWN),
+  mUserTime(0),
+  mAction(CONTENT_ACTION_NONE)
 {
 	LOG ("GContentHandler ctor (%p)", this);
 }
@@ -84,6 +88,8 @@ GContentHandler::Show (nsIHelperAppLauncher *aLauncher,
 		       nsISupports *aContext,
 		       PRUint32 aReason)
 {
+        nsRefPtr<GContentHandler> kungFuDeathGrip(this);
+
 	nsresult rv;
 	EphyEmbedSingle *single;
 	gboolean handled = FALSE;
@@ -220,10 +226,10 @@ NS_METHOD GContentHandler::Init ()
 	return NS_OK;
 }
 
-static void
-response_cb (GtkWidget *dialog,
-	     int response,
-	     GContentHandler *self)
+/* static */ void
+GContentHandler::ResponseCallback (GtkWidget *dialog,
+                                   int response,
+                                   GContentHandler *self)
 {
 	gtk_widget_destroy (dialog);
 
@@ -345,7 +351,7 @@ NS_METHOD GContentHandler::MIMEConfirmAction ()
 
 	NS_ADDREF_THIS();
 	g_signal_connect_data (dialog, "response",
-			       G_CALLBACK (response_cb), this,
+			       G_CALLBACK (ResponseCallback), this,
 			       (GClosureNotify) release_cb, (GConnectFlags) 0);
 
 	/* FIXME: should find a way to get the user time of the user action which
@@ -364,7 +370,7 @@ NS_METHOD GContentHandler::MIMEInitiateAction (void)
 
 	auto_downloads = eel_gconf_get_boolean (CONF_AUTO_DOWNLOADS);
 
-	mHelperApp = g_app_info_get_default_for_type (mMimeType.get(), TRUE);
+	mHelperApp = g_app_info_get_default_for_type (mMimeType.get(), FALSE);
 	mPermission = ephy_file_check_mime (mMimeType.get());
 
 	/* HACK! Check that this 'helper application' isn't Epiphany itself,
@@ -381,11 +387,13 @@ NS_METHOD GContentHandler::MIMEInitiateAction (void)
 		}
 	}
 
+#ifndef HAVE_GECKO_1_9
 	if (auto_downloads)
 	{
 		mAction = CONTENT_ACTION_OPEN;
 	}
 	else
+#endif /* !HAVE_GECKO_1_9 */
 	{
 		mAction = CONTENT_ACTION_OPEN_TMP;
 	}
@@ -410,7 +418,7 @@ NS_METHOD GContentHandler::MIMEInitiateAction (void)
 NS_METHOD GContentHandler::MIMEDoAction (void)
 {
 	/* This is okay, since we either clicked on a button, or we get 0 */
-	mUserTime = gtk_get_current_event_time ();
+	mUserTime = (PRUint32) gtk_get_current_event_time ();
 
 	nsCOMPtr<nsIMIMEInfo> mimeInfo;
 	mLauncher->GetMIMEInfo(getter_AddRefs(mimeInfo));
@@ -454,6 +462,8 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 	}
 #endif /* HAVE_GECKO_1_9 */
 
+        nsRefPtr<GContentHandler> kungFuDeathGrip(this);
+
 	if (mAction == CONTENT_ACTION_OPEN)
 	{
 		mLauncher->SaveToDisk (nsnull, PR_FALSE);
