@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyHistoryListener.cpp 6588 2006-09-13 11:34:25Z chpe $
+ *  $Id: EphyHistoryListener.cpp 7426 2007-09-13 13:18:57Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -63,7 +63,7 @@ EphyHistoryListener::Init (EphyHistory *aHistory)
 	NS_ENSURE_TRUE (NS_SUCCEEDED (rv) && webProgress, rv);
 		
 	rv = webProgress->AddProgressListener
-			(NS_STATIC_CAST(nsIWebProgressListener*,this),
+			(static_cast<nsIWebProgressListener*>(this),
 			 nsIWebProgress::NOTIFY_STATE_REQUEST);
 
 	return rv;
