@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EventContext.cpp 7426 2007-09-13 13:18:57Z chpe $
+ *  $Id: EventContext.cpp 8246 2008-05-23 21:12:37Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -968,9 +968,10 @@ nsresult EventContext::SetStringProperty (const char *name, const char *value)
 	GValue *val = g_new0 (GValue, 1);
 
 	g_value_init (val, G_TYPE_STRING);
-	
-	g_value_set_string (val, value);
-			 
+
+	char *copy = g_strstrip (g_strdup (value));	
+	g_value_take_string (val, copy);
+
 	mozilla_embed_event_set_property (mEmbedEvent, name, val);
 
 	return NS_OK;
