@@ -16,12 +16,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: GlobalHistory.h 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id: GlobalHistory.h 8226 2008-05-18 21:49:56Z chpe $
  */
 
 #ifndef EPHY_GLOBAL_HISTORY_H
 #define EPHY_GLOBAL_HISTORY_H
 
+#ifdef HAVE_GECKO_1_9
+#include <nsIDownloadHistory.h>
+#endif
 #ifdef HAVE_NSIGLOBALHISTORY3_H
 #include <nsIGlobalHistory3.h>
 #else
@@ -49,6 +52,9 @@ class MozGlobalHistory: public nsIGlobalHistory3
 #else
 class MozGlobalHistory: public nsIGlobalHistory2
 #endif /* HAVE_NSIGLOBALHISTORY3_H */
+#ifdef HAVE_GECKO_1_9
+                       , public nsIDownloadHistory
+#endif
 {
 	public:
 		MozGlobalHistory ();
@@ -59,6 +65,9 @@ class MozGlobalHistory: public nsIGlobalHistory2
 #ifdef HAVE_NSIGLOBALHISTORY3_H
 		NS_DECL_NSIGLOBALHISTORY3
 #endif /* HAVE_NSIGLOBALHISTORY3_H */
+#ifdef HAVE_GECKO_1_9
+                NS_DECL_NSIDOWNLOADHISTORY
+#endif
 
 	private:
 		EphyHistory *mGlobalHistory;
