@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp 7888 2008-01-24 19:14:16Z cosimoc $
+ * $Id: MozDownload.cpp 8153 2008-03-28 15:08:18Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -349,12 +349,26 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 		}
 		else if (NS_SUCCEEDED (aStatus))
 		{
-			/* see http://bugzilla.gnome.org/show_bug.cgi?id=456945 */
+			NS_ENSURE_TRUE (mMIMEInfo, NS_ERROR_FAILURE);
 #ifdef HAVE_GECKO_1_9
-			return NS_OK;
+                        nsHandlerInfoAction action;
+                        mMIMEInfo->GetPreferredAction(&action);
+
+                        if (action == EPHY_ACTION_BROWSE_TO_FILE) {
+                                nsCString destSpec;
+                                rv = mDestination->GetSpec (destSpec);
+                                NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+
+                                GFile *dest;
+                                dest = g_file_new_for_uri (destSpec.get ());
+                                ephy_file_browse_to (dest, 0 /* FIXME BUG BUG BUG */);
+                                g_object_unref (dest);
+                        }
+                        /* All other values are handled by gecko itself */
+
+                        return NS_OK;
 #else
 			GDesktopAppInfo *helperApp;
-			NS_ENSURE_TRUE (mMIMEInfo, NS_ERROR_FAILURE);
 
 			nsString description;
 			mMIMEInfo->GetApplicationDescription (description);
