@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-main.c 7506 2007-09-28 21:45:48Z diegoe $
+ *  $Id: ephy-main.c 8247 2008-05-23 21:45:02Z chpe $
  */
 
 #include "config.h"
@@ -47,8 +47,6 @@
 #include <libgnome/gnome-program.h>
 #include <libgnomeui/gnome-ui-init.h>
 
-#include <libgnomevfs/gnome-vfs-init.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomeui/gnome-app-helper.h>
 
 #include <errno.h>
@@ -203,11 +201,24 @@ handle_email (GtkAboutDialog *about,
 	      const char *link,
 	      gpointer data)
 {
-	char *address;
+	char *command, *handler;
+	GAppInfo *appinfo;
 
-	address = g_strdup_printf ("mailto:%s", link);
-	gnome_vfs_url_show (address);
-	g_free (address);
+	if (eel_gconf_get_boolean ("/desktop/gnome/url-handlers/mailto/enabled") == FALSE)
+	{
+		return;
+	}
+	/* FIXME: better use g_app_info_get_default_for_uri_scheme () when it is
+	 * implemented.
+	 */
+	handler = eel_gconf_get_string ("/desktop/gnome/url-handlers/mailto/command");
+	command = g_strconcat (handler, "mailto:", link, NULL);
+	appinfo = g_app_info_create_from_commandline (command, NULL, 0, NULL);
+	ephy_file_launch_application (appinfo, NULL,
+				      gtk_get_current_event_time (),
+				      GTK_WIDGET (about));
+	g_free (handler);
+	g_free (command);
 }
 
 static void
@@ -369,7 +380,7 @@ queue_commands (guint32 user_time)
 		}
 		if (open_in_new_tab)
 		{
-			g_string_append (options, "new-tab,");
+			g_string_append (options, "new-tab,external,");
 		}
 
 		ephy_session_queue_command (session,
@@ -544,6 +555,11 @@ main (int argc,
 		g_print ("--profile can only be used in combination with --private-instance\n");
 		exit (1);
 	}
+	if (profile_directory != NULL && !g_path_is_absolute (profile_directory))
+	{
+		g_printerr ("The profile directory must be specified with an absolute path.\n");
+		exit (1);
+	}
 
 	if (arguments != NULL &&
 	    eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_ARBITRARY_URL))
@@ -585,12 +601,15 @@ main (int argc,
 			{
 				g_free (arguments[i]);
 
-				/* If it's a file, use gnome_vfs_make_uri_from_shell_arg,
+				/* If it's a file, use g_file_new_for_commandline_arg,
 				 * so we get the right escaping.
 				 */
 				if (path != NULL)
 				{
-					arguments[i] = gnome_vfs_make_uri_from_shell_arg (uri);
+					GFile *file;
+					file = g_file_new_for_commandline_arg (uri);
+					arguments[i] = g_file_get_uri (file);
+					g_object_unref (file);
 					g_free (uri);
 				}
 				else
@@ -727,7 +746,6 @@ main (int argc,
 	gnome_accelerators_sync ();
 	ephy_state_save ();
 	ephy_file_helpers_shutdown ();
-	gnome_vfs_shutdown ();
 	xmlCleanupParser ();
 
 	_ephy_dbus_release ();
