@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: popup-commands.c 7888 2008-01-24 19:14:16Z cosimoc $
+ *  $Id: popup-commands.c 7981 2008-02-25 19:37:26Z chpe $
  */
 
 #include "config.h"
@@ -486,7 +486,7 @@ popup_cmd_open_image (GtkAction *action,
 	value = ephy_embed_event_get_property (event, "image");
 	address = g_value_get_string (value);
 
-	scheme = g_uri_get_scheme (address);
+	scheme = g_uri_parse_scheme (address);
 	if (scheme == NULL) return;
 
 	if (strcmp (scheme, "file") == 0)
